from src.gaussian_distribution import Gaussian
from src.binomial_distribution import Binomial
__version__ = '1.0'
__name_='practice_distribution_msrk'
__description_='Gaussian distributions'
__packages_=['practice_distribution_msrk']
__zip_safe_=False
__author_='Satya Rohith Kumar'
__author_email_='rohithmeduri24@gmail.com'
__requires_=['matplotlib','math']


from setuptools import setup

setup(name='practice_distribution_msrk',
      version='1.0',
      description='Gaussian distributions',
      packages=['practice_distribution_msrk'],
      zip_safe=False,
      author='Satya Rohith Kumar',
      author_email='rohithmeduri24@gmail.com',
      requires=['matplotlib','math'],)
